LiveFox.Notify = {

  FLASH_SECONDS: 20,

  showHeaderImages: true,

  showNotify: true,

  eventList: [], // array of events

  matchEventList: null, // object with list of events grouped by match

  parentList: [], // array with box DOM elements that have images of events

  flashList: [],

  flashCounter: 0,

  alertTimer: 0,

  MatchEvent: function(match) {

    this.match = match;

    this.home = new Array(); // array with home events

    this.away = new Array(); // array with away events

    this.homeAlert = Events.type.NONE;

    this.awayAlert = Events.type.NONE;

    this.matchAlert = Events.type.NONE;

    this.flashCounter=0;

  },

  startTimeoutClear: function() {

      setTimeout("LiveFox.Notify.clearImages()", 45000);

      setTimeout("LiveFox.Notify.clearFlash()", 20000);

  },

  startAlert: function(title, text) {

      setTimeout(LiveFox.Notify.showAlert, (this.alertTimer++)*5000, title, text);

  },

  flash: function() {

    var className, matchEv;

    try {

      if (LiveFox.Notify.flashList.length == 0) return;

      for (var i=0; i<LiveFox.Notify.flashList.length; i++) {

        matchEv = LiveFox.Notify.flashList[i];

        className = (matchEv.flashCounter++ % 2) == 1 ? matchEv.matchAlert.color.cssClass : LiveFox.Notify.color.white.cssClass;

        document.getElementById("placardbox_"+matchEv.match.id).className = className;

      }

      setTimeout(LiveFox.Notify.flash, 750);

    } catch(e) {

      LiveFox.Log.error("Notify.flash: " + e);

    }

  },

  showAlert: function(title, text) {

    try {

      var alertService = Components.classes["@mozilla.org/alerts-service;1"]

                        .getService(Components.interfaces.nsIAlertsService);

      alertService.showAlertNotification(

                        LiveFox.Image.livefox,

                        title,

                        text,

                        false, "", null);

    } catch (e) {

      LiveFox.Log.error(e);

    }

  },

  add: function(event) {

    if (event.isInfo()) return;

    this.eventList.push(event);

  },

  set: function() {

    

    // check the list of events occured in the last update

    this.matchEventList = new Object();

    for (var i=0; i<this.eventList.length; i++) {

      var ev=this.eventList[i];

      //if (ev.type.id != 120) continue; // TODO: remove after debug

      var match = ev.match;

      var matchEvent = this.matchEventList["_"+match.id]; 

      if (!matchEvent) {

        matchEvent = new this.MatchEvent(match);

        this.matchEventList["_"+match.id] = matchEvent;

      }

      if (match.isHomeTeam(ev.subjectTeamId)) {

        matchEvent.home.push(ev);

        if (ev.type.id < matchEvent.homeAlert.id) {

          matchEvent.homeAlert = ev.type;

        }

      } else if (match.isAwayTeam(ev.subjectTeamId)) {

        matchEvent.away.push(ev);

        if (ev.type.id < matchEvent.awayAlert.id) {

          matchEvent.awayAlert = ev.type;

        }

      }

    }



    // put events's image in the match header 

    for (var matchEventName in this.matchEventList) {

      var matchEvent = this.matchEventList[matchEventName];

      var match = matchEvent.match;

      

      // home team events

      if (matchEvent.home.length > 0) {

        var box = document.getElementById("header_home_team_notify_"+match.id);

        for (var i=0; i<matchEvent.home.length; i++) {

          var ev = matchEvent.home[i];

          img = document.createElement("image");

          box.appendChild(img);

          img.setAttribute("src", ev.type.imageSrc);

          if (matchEvent.homeAlert.id > ev.type.id) matchEvent.homeAlert = ev.type;

        }

        this.parentList.push(box);

      }

      

      // away team events

      if (matchEvent.away.length > 0) {

        var box = document.getElementById("header_away_team_notify_"+match.id);

        for (var i=matchEvent.away.length-1; i>=0; i--) {

          var ev = matchEvent.away[i];

          img = document.createElement("image");

          box.appendChild(img);

          img.setAttribute("src", ev.type.imageSrc);

          if (matchEvent.awayAlert.id > ev.type.id) matchEvent.awayAlert = ev.type;

        }

        this.parentList.push(box);

      }



      // put most important(?) event in the slider and plays sound

      matchEvent.matchAlert = (

                    matchEvent.homeAlert.id < matchEvent.awayAlert.id

                    ? matchEvent.homeAlert : matchEvent.awayAlert);



      var alertEv = matchEvent.matchAlert; 



      if (LiveFox.prefs.notification.slider) {

        if (alertEv.text) {

          this.startAlert(alertEv.text,

                            LiveFox.DOM.getTextContent(match.home.team.name)

                            + " " + match.home.goals + " : "

                            + match.away.goals + " "

                            + LiveFox.DOM.getTextContent(match.away.team.name));

        }

      }

      

      if (LiveFox.prefs.notification.sound) {

        if (!LiveFox.prefs.notification.soundOnlyOpened

            || document.getElementById("live_" + matchEvent.match.id).hidden==false) {

          if (alertEv.sound) {

            alertEv.sound.play();

          }

        }

      }



      if (alertEv.color) {

        this.flashList.push(matchEvent);

      }

    };

    

    

    LiveFox.Log.properties(this.matchEventList, "MatchEventList:");



    this.startTimeoutClear();  

    if (LiveFox.prefs.notification.flash) {

      this.flash();

    }

  },

  clearImages: function() {

    var clearNotify = function(parent, i, parentList) {

      var child;

      while((child = parent.firstChild)) {

        parent.removeChild(child);

      }

      

    };

    if (this.eventList.length != 0) {

      this.parentList.forEach(clearNotify, LiveFox.Notify);

      this.eventList = [];

      this.parentList = [];

    }

    this.alertTimer = 0;

  },

  clearFlash: function() {

    for (var i=0; i<this.flashList.length; i++) {

      document.getElementById("placardbox_"+this.flashList[i].match.id).className = "";

      this.flashList[i].flashCounter=0;

    }

    this.flashList = [];

  }

}



LiveFox.Notify.Color = function(css) {

  this.cssClass = css;

};



LiveFox.Notify.color = {

  white: new LiveFox.Notify.Color("background_white"),

  orange: new LiveFox.Notify.Color("background_orange"),

  yellow: new LiveFox.Notify.Color("background_yellow"),

  green: new LiveFox.Notify.Color("background_green"),

  red: new LiveFox.Notify.Color("background_red"),

  grey: new LiveFox.Notify.Color("background_grey"),

  blue: new LiveFox.Notify.Color("background_blue")

};





LiveFox.Notify.Color.prototype.toString = function() {

  return (this.cssClass);

};



LiveFox.Notify.MatchEvent.prototype.toString = function() {

  return (this.match.id + "," + this.home.length + "," + this.away.length);

};





